/*
             LUFA Library
     Copyright (C) Dean Camera, 2011.

  dean [at] fourwalledcubicle [dot] com
           www.lufa-lib.org
*/

/*
  Copyright 2011  Dean Camera (dean [at] fourwalledcubicle [dot] com)

  Permission to use, copy, modify, distribute, and sell this
  software and its documentation for any purpose is hereby granted
  without fee, provided that the above copyright notice appear in
  all copies and that both that the copyright notice and this
  permission notice and warranty disclaimer appear in supporting
  documentation, and that the name of the author not be used in
  advertising or publicity pertaining to distribution of the
  software without specific, written prior permission.

  The author disclaim all warranties with regard to this
  software, including all implied warranties of merchantability
  and fitness.  In no event shall the author be liable for any
  special, indirect or consequential damages or any damages
  whatsoever resulting from loss of use, data or profits, whether
  in an action of contract, negligence or other tortious action,
  arising out of or in connection with the use or performance of
  this software.
*/

/** \file
 *  \brief Supported architecture defines.
 *
 *  This file contains constants which can be passed to the compiler (via setting the macro ARCH) in the
 *  user project makefile using the -D option to configure the library drivers.
 *
 *  \note Do not include this file directly, rather include the Common.h header file instead to gain this file's
 *        functionality.
 */

/** \ingroup Group_Common
 *  \defgroup Group_Architectures Hardware Architectures
 *
 *  Macros for indicating the chosen hardware architecture to the library. These macros should be used when
 *  defining the ARCH token to the chosen hardware via the -D switch in the project makefile.
 *
 *  @{
 */

#ifndef __LUFA_ARCHITECTURES_H__
#define __LUFA_ARCHITECTURES_H__

	/* Preprocessor Checks: */
		#if !defined(__INCLUDE_FROM_COMMON_H)
			#error Do not include this file directly. Include LUFA/Common/Common.h instead to gain this functionality.
		#endif

	/* Public Interface - May be used in end-application: */
		/* Macros: */
			/** Selects the Atmel 8-bit AVR (AT90USB* and ATMEGA*U* chips) architecture. */
			#define ARCH_AVR8           1

			#if !defined(__DOXYGEN__)
				#define ARCH_           ARCH_AVR8

				#if !defined(ARCH)
					#define ARCH        ARCH_AVR8
				#endif
			#endif

#endif

/** @} */

